Talks
=====

2013 August 27 - Boulder Django
-------------------------------

You can see the slides for "django-authtools, Custom User Model for
Everyone!" given at `Boulder Django
<http://www.meetup.com/boulder-django/>`_ on `Speaker Deck
<https://speakerdeck.com/aaronmerriam/django-authtools-a-custom-user-model-for-everyone>`_.
